# eric7.Plugins.VcsPlugins.vcsGit.GitBranchDialog

Module implementing a dialog to enter the data for a branching operation.

### Global Attributes

None

### Classes

GitBranchDialog | Class implementing a dialog to enter the data for a branching operation.

### Functions

None

## GitBranchDialog

Class implementing a dialog to enter the data for a branching operation.

### Derived from

QDialog, Ui_GitBranchDialog

### Class Attributes

CreateBranch
CreateSwitchBranch
CreateTrackingBranch
DeleteBranch
RenameBranch
SetTrackingBranch
UnsetTrackingBranch

### Class Methods

None

### Methods

GitBranchDialog | Constructor
__updateOK | Private method used to enable/disable the OK-button.
getParameters | Public method to retrieve the branch data.
on_branchCombo_editTextChanged | Private slot to handle a change of the branch.
on_createTrackingButton_toggled | Private slot to handle the selection of creating a tracking branch.
on_newBranchNameEdit_textChanged | Private slot to handle a change of the new branch.
on_setTrackingButton_toggled | Private slot to handle the selection of setting a tracking branch.
on_unsetTrackingButton_toggled | Private slot to handle the selection of unsetting a tracking branch.

### Static Methods

None

#### GitBranchDialog (Constructor)

GitBranchDialog(branchlist, revision=None, branchName=None, branchOp=None, parent=None)

Constructor

branchlist
  list of previously entered branches (list of strings)
revision
  revision to set tag for (string)
branchName
  name of the branch (string)
branchOp
  desired branch operation (integer)
parent
  parent widget (QWidget)

#### GitBranchDialog.__updateOK

__updateOK()

Private method used to enable/disable the OK-button.

#### GitBranchDialog.getParameters

getParameters()

Public method to retrieve the branch data.

Return:
  tuple of an int, four strings and a boolean (branch operation, branch name, revision, new branch name, remote branch name, enforce operation)

#### GitBranchDialog.on_branchCombo_editTextChanged

on_branchCombo_editTextChanged(text)

Private slot to handle a change of the branch.

text
  branch name entered in the combo (string)

#### GitBranchDialog.on_createTrackingButton_toggled

on_createTrackingButton_toggled(checked)

Private slot to handle the selection of creating a tracking branch.

checked
  state of the selection (boolean)

#### GitBranchDialog.on_newBranchNameEdit_textChanged

on_newBranchNameEdit_textChanged(text)

Private slot to handle a change of the new branch.

text
  new branch name entered (string)

#### GitBranchDialog.on_setTrackingButton_toggled

on_setTrackingButton_toggled(checked)

Private slot to handle the selection of setting a tracking branch.

checked
  state of the selection (boolean)

#### GitBranchDialog.on_unsetTrackingButton_toggled

on_unsetTrackingButton_toggled(checked)

Private slot to handle the selection of unsetting a tracking branch.

checked
  state of the selection (boolean)

Up